AppRouteGet class

Constructors

AppRouteGet({required String path, String? name = null, String? transition = null})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transition String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited