GetTransition class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- circularReveal → const String
- cupertino → const String
- cupertinoDialog → const String
- downToUp → const String
- fade → const String
- fadeIn → const String
- leftToRight → const String
- leftToRightWithFade → const String
- native → const String
- noTransition → const String
- rightToLeft → const String
- rightToLeftWithFade → const String
- size → const String
- topLevel → const String
- upToDown → const String
- zoom → const String